package es.uca.xmleye.gui.html;

/////////////////////////////////////////////////////////
//  Bare Bones Browser Launch                          //
//  Version 1.5                                        //
//  December 10, 2005                                  //
//  Supports: Mac OS X, GNU/Linux, Unix, Windows XP    //
//  Example Usage:                                     //
//     String url = "http://www.centerkey.com/";       //
//     BrowserLauncher.abrirURL(url);                //
//  Public Domain Software -- Free to Use as You Like  //
/////////////////////////////////////////////////////////

import java.util.*;
import java.lang.reflect.Method;
import javax.swing.JOptionPane;

/**
 * Lanzador de navegador web con soporte para GNU/Linux, Windows XP y Mac OS X.
 * 
 * @author <a href="http://www.centerkey.com">Center Key Software</a> (dominio
 *         público)
 * @author Antonio García Domínguez (añadido mensajes de error
 *         internacionalizados, retirado excepción, limpiado)
 * @version 1.5
 */
class BrowserLauncher {
	private static final ResourceBundle errRes;
	static {
		errRes = ResourceBundle.getBundle("es.uca.xmleye.l10n.ErrorMessages",
				Locale.getDefault());
	}

	/**
	 * Abre la dirección <code>url</code> en un navegador web. En los SO que
	 * lo soporten, se usará el predeterminado. De lo contrario, se probará con
	 * una lista de navegadores conocidos, que deben hallarse en el PATH.
	 * 
	 * @param url
	 *            Dirección a mostrar.
	 */
	@SuppressWarnings("unchecked")
	public static void abrirURL(String url) {
		String nombreOS = System.getProperty("os.name");

		try {
			if (nombreOS.startsWith("Mac OS")) {
				Method abrirURL = String.class.getDeclaredMethod("openURL");
				abrirURL.invoke(null, new Object[] { url });
			} else if (nombreOS.startsWith("Windows")) {
				Runtime.getRuntime().exec(
						"rundll32 url.dll,FileProtocolHandler " + url);
			} else {
				// Unix o GNU/Linux: lanzaremos un navegador gráfico.
				String[] navegadores = { "firefox", "opera", "konqueror",
						"epiphany", "mozilla", "netscape" };

				String navegador = null;
				for (int i = 0; i < navegadores.length && navegador == null; i++) {
					if (Runtime.getRuntime().exec(
							new String[] { "which", navegadores[i] }).waitFor() == 0) {
						navegador = navegadores[i];
						break;
					}
				}

				if (navegador == null) {
					// No se halló ningún navegador útil
					JOptionPane.showMessageDialog(null, String.format(errRes
							.getString("err_launch_browser"), url));
				} else
					Runtime.getRuntime().exec(new String[] { navegador, url });
			}
		} catch (Exception e) {
			JOptionPane.showMessageDialog(null, String.format(errRes
					.getString("err_launch_browser"), url)
					+ ":\n" + e.getLocalizedMessage());
		}
	}
}
