package es.uca.xmleye.gui.util;

/*
 Copyright (C) 2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA
 */

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;
import javax.swing.Action;
import javax.swing.ButtonGroup;
import javax.swing.JMenu;
import javax.swing.JRadioButtonMenuItem;

public class RadioSelectMenu extends JMenu implements ActionListener {
	/**
	 * 
	 */
	private static final long serialVersionUID = 7479881165799010906L;
	private String claveSel;

	/**
	 * Crea un menú que permite elegir entre varias claves (no se guardan
	 * valores para ninguna clave), con una selección inicial.
	 */
	public RadioSelectMenu(Action a, List<String> elems, String claveSel) {
		super(a);
		this.claveSel = claveSel;

		ButtonGroup grupoBotones = new ButtonGroup();

		for (String elem : elems) {
			JRadioButtonMenuItem radioItem = new JRadioButtonMenuItem(elem);
			radioItem.addActionListener((ActionListener) this);

			grupoBotones.add(radioItem);
			this.add(radioItem);

			if (elem.equals(this.claveSel)) {
				radioItem.setSelected(true);
			}
		}
	}

	/** Cambia la clave seleccionada (si es que existe), sin lanzar un evento. */
	public void setSeleccion(String s) {
		if (s.equals(getSeleccion()))
			return;

		for (int i = 0; i < getItemCount(); ++i) {
			if (getItem(i).getText().equals(s)) {
				claveSel = s;
				getItem(i).setSelected(true);
			}
		}
	}

	/** Obtiene la clave seleccionada actualmente. */
	public String getSeleccion() {
		return claveSel;
	}

	/**
	 * Genera un ActionEvent con el elemento seleccionado en el parámetro
	 * command.
	 */
	public void actionPerformed(ActionEvent e) {
		String nuevaClave = ((JRadioButtonMenuItem) e.getSource()).getText();

		if (!this.claveSel.equals(nuevaClave)) {
			this.claveSel = nuevaClave;

			fireActionPerformed(new ActionEvent(this,
					ActionEvent.ACTION_PERFORMED, claveSel));
		}
	}
}
